"""
safemd – Safety first markdown rendering

Author: Alexander Hultnér, 2018

"""

from typing import Optional
from cmarkgfm.cmark import markdown_to_html, github_flavored_markdown_to_html, Options
from .clean import clean


def render(
    content: str,
    flavour: str = "",
    *,
    UNSAFE_NO_BLEACH: bool = False,
    UNSAFE_CMARK_XSS: bool = False,
) -> Optional[str]:

    if not content:
        # No content, nothing to do here
        return None

    if flavour.lower() in ["gfm", "github"]:
        md_render = github_flavored_markdown_to_html
    else:
        md_render = markdown_to_html

    if UNSAFE_CMARK_XSS:
        # Use unsafe rendering in cmark
        options = 0
    else:
        options = Options.CMARK_OPT_SAFE

    output = md_render(content, options=options)

    if UNSAFE_NO_BLEACH or output is None:
        # No bleach or no output from renderer
        return output

    return clean(output)



"""
Markdown input examples for testing

Author: Alexander Hultnér
"""


unsafe_xss = """
[Just a link](javascript:alert("hi"))

[Normal link](data:text/html;base64,PHNjcmlwdD5hbGVydCgiSGkiKTwvc2NyaXB0Pgo=)

[Nothing fishy here](data:text/html;base64,PHNjcmlwdCBzcmM9Imh0dHBzOi8vZ2lzdGNkbi5naXRoYWNrLmNvbS9IdWx0bmVyL2JjMDIzOGJkOWIxZDI4M2JhMWM5NDczZjU0M2ZmZjc4L3Jhdy9kM2U5YWFkYTdlMGRlNzFkNmNlYTY1MDVmMTljZGE2NjE1MmE0MDFlL2hpLmpzIiBpbnRlZ3JpdHk9InNoYTM4NC0yaGZ6aFlkelB1SGd0S1E2Vk96UGlNbEN2Nzl3WDM1NzdxTDR3eWpmNWhMYkEvcW1BZHhCbXdxNGl6YXRwRy93IiBjcm9zc29yaWdpbj0iYW5vbnltb3VzIj48L3NjcmlwdD4=)
"""



"""
Expected outputs from safemd

Author: Alexander Hultnér
"""

default = '<p><a href="" rel="nofollow">Just a link</a></p>\n<p><a href="" rel="nofollow">Normal link</a></p>\n<p><a href="" rel="nofollow">Nothing fishy here</a></p>\n'

NO_BLEACH = '<p><a href="">Just a link</a></p>\n<p><a href="">Normal link</a></p>\n<p><a href="">Nothing fishy here</a></p>\n'

CMARK_XSS = "<p><a>Just a link</a></p>\n<p><a>Normal link</a></p>\n<p><a>Nothing fishy here</a></p>\n"

CMARK_XSS_NO_BLEACH = '<p><a href="javascript:alert(%22hi%22)">Just a link</a></p>\n<p><a href="data:text/html;base64,PHNjcmlwdD5hbGVydCgiSGkiKTwvc2NyaXB0Pgo=">Normal link</a></p>\n<p><a href="data:text/html;base64,PHNjcmlwdCBzcmM9Imh0dHBzOi8vZ2lzdGNkbi5naXRoYWNrLmNvbS9IdWx0bmVyL2JjMDIzOGJkOWIxZDI4M2JhMWM5NDczZjU0M2ZmZjc4L3Jhdy9kM2U5YWFkYTdlMGRlNzFkNmNlYTY1MDVmMTljZGE2NjE1MmE0MDFlL2hpLmpzIiBpbnRlZ3JpdHk9InNoYTM4NC0yaGZ6aFlkelB1SGd0S1E2Vk96UGlNbEN2Nzl3WDM1NzdxTDR3eWpmNWhMYkEvcW1BZHhCbXdxNGl6YXRwRy93IiBjcm9zc29yaWdpbj0iYW5vbnltb3VzIj48L3NjcmlwdD4=">Nothing fishy here</a></p>\n'



#!usr/bin/env python3
"""
safemd – Safety first markdown rendering

Author: Alexander Hultnér, 2018
"""

from setuptools import setup, find_packages

with open("README.md") as f:
    long_description = f.read()

setup(
    name="safemd",
    author="Alexander Hultnér",
    author_email="ahultner@gmail.com",
    maintainer="Alexander Hultnér",
    maintainer_email="ahultner@gmail.com",
    url="https://github.com/Hultner/safemd/",
    description="A markdown renderer focusing on security first",
    long_description=long_description,
    long_description_content_type="text/markdown",
    version="18.10.4",
    py_modules=["safemd"],
    packages=find_packages(exclude=["tests"]),
    install_requires=["cmarkgfm", "bleach"],
    extras_require={"dev": ["black", "pytest", "twine", "pytest-cov", "codacy-coverage"]},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.6",
)
